@@ -46,9 +46,7 @@ sub data {
                 useColumnShortNames => 'true',
     };
 
-    my $params = $self->ua->www_form_urlencode( $query );
-
-    return $self->get_response( $url );
+    return $self->get_response( $url, $query );
 }
 
 sub get_path {
@@ -75,6 +73,16 @@ sub zip {
     return $response;
 }
 
+=head2 parse_data
+
+Takes the output from the C<data> method and uses Text::CSV
+to read each line, returning an arrayref of rows.
+
+If the parsing throws an error, it bails warning you to save
+the file and parse it in full.
+
+=cut
+
 sub parse_data {
     my ($self, $body) = @_;
 
